<?php

namespace Nwb\S3;

/**
 * Classe ConfigS3
 *
 * Génère un objet de configuration pour AWS S3 en utilisant des variables d'environnement
 * et permet une surcharge via des propriétés.
 */
class ConfigS3
{
    private $accessKey;
    private $secretKey;
    private $bucket;
    private $region;
    private $endpoint;
    private $encryptionKey;

    /**
     * Constructeur
     */
    public function __construct()
    {
        $this->accessKey = getenv('AWS_ACCESS_KEY_ID');
        $this->secretKey = getenv('AWS_SECRET_ACCESS_KEY');
        $this->bucket = getenv('AWS_BUCKET');
        $this->region = getenv('AWS_REGION') ?? 'fr-par';
        $this->endpoint = getenv('AWS_ENDPOINT') ?? 's3.fr-par.scw.cloud';
        $this->encryptionKey = getenv('AWS_S3_ENCRYPTION_KEY');
    }

    /**
     * Permet de surcharger la configuration.
     *
     * @param array $config Tableau associatif des valeurs de configuration.
     */
    public function setConfig(array $config): void
    {
        foreach ($config as $key => $value) {
            if (property_exists($this, $key)) {
                $this->{$key} = $value;
            }
        }
    }

    /**
     * Retourne l'objet de configuration pour AWS S3.
     *
     * @return array Objet de configuration.
     */
    public function getConfig(): array
    {
        return [
            'region' => $this->region,
            'version' => 'latest',
            'credentials' => [
                'key' => $this->accessKey,
                'secret' => $this->secretKey,
            ],
            'endpoint' => $this->endpoint
        ];
    }

    /**
     * Retourne le nom du Bucket
     * @return string Nom du Bucket
     */
    public function getBucket(): string
    {
        return $this->bucket;
    }

    public function getEncryptionKey()
    {
        return $this->encryptionKey;
    }

    /**
     * Définit la clé de chiffrement.
     *
     * @param string $encryptionKey La clé de chiffrement à utiliser.
     */
    public function setEncryptionKey($encryptionKey)
    {
        $this->encryptionKey = $encryptionKey;
    }
}
